@@ -1,13 +1,13 @@
 package Parse::VarName;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-06-14'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use Exporter::Lite;
+use Exporter qw(import);
 our @EXPORT_OK = qw(split_varname_words);
 
 our %SPEC;
@@ -87,7 +87,7 @@ Parse::VarName - Routines to parse variable name
 
 =head1 VERSION
 
-This document describes version 0.02 of Parse::VarName (from Perl distribution Parse-VarName), released on 2015-09-03.
+This document describes version 0.03 of Parse::VarName (from Perl distribution Parse-VarName), released on 2016-06-14.
 
 =head1 FUNCTIONS
 
@@ -99,6 +99,8 @@ Split words found in variable name.
 Try to split words found in a variable name, e.g. mTime -> [m, Time], foo1Bar ->
 [foo, 1, Bar], Foo::barBaz::Qux2 -> [Foo, bar, Baz, Qux, 2].
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -138,7 +140,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
